#[non_exhaustive]pub struct ListCalculationExecutionsOutputBuilder { /* private fields */ }Expand description
A builder for ListCalculationExecutionsOutput.
Implementations
Sourceimpl ListCalculationExecutionsOutputBuilder
impl ListCalculationExecutionsOutputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn calculations(self, input: CalculationSummary) -> Self
pub fn calculations(self, input: CalculationSummary) -> Self
Appends an item to calculations.
To override the contents of this collection use set_calculations.
A list of CalculationSummary objects.
Sourcepub fn set_calculations(self, input: Option<Vec<CalculationSummary>>) -> Self
pub fn set_calculations(self, input: Option<Vec<CalculationSummary>>) -> Self
A list of CalculationSummary objects.
Sourcepub fn get_calculations(&self) -> &Option<Vec<CalculationSummary>>
pub fn get_calculations(&self) -> &Option<Vec<CalculationSummary>>
A list of CalculationSummary objects.
Sourcepub fn build(self) -> ListCalculationExecutionsOutput
pub fn build(self) -> ListCalculationExecutionsOutput
Consumes the builder and constructs a ListCalculationExecutionsOutput.