pub struct ListCalculationExecutionsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListCalculationExecutions.
Lists the calculations that have been submitted to a session in descending order. Newer calculations are listed first; older calculations are listed later.
Implementations
Sourceimpl ListCalculationExecutionsFluentBuilder
impl ListCalculationExecutionsFluentBuilder
Sourcepub fn as_input(&self) -> &ListCalculationExecutionsInputBuilder
pub fn as_input(&self) -> &ListCalculationExecutionsInputBuilder
Access the ListCalculationExecutions as a reference.
Sourcepub async fn send(
self,
) -> Result<ListCalculationExecutionsOutput, SdkError<ListCalculationExecutionsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListCalculationExecutionsOutput, SdkError<ListCalculationExecutionsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListCalculationExecutionsOutput, ListCalculationExecutionsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListCalculationExecutionsOutput, ListCalculationExecutionsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListCalculationExecutionsPaginator
pub fn into_paginator(self) -> ListCalculationExecutionsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session ID.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session ID.
Sourcepub fn state_filter(self, input: CalculationExecutionState) -> Self
pub fn state_filter(self, input: CalculationExecutionState) -> Self
A filter for a specific calculation execution state. A description of each state follows.
CREATING - The calculation is in the process of being created.
CREATED - The calculation has been created and is ready to run.
QUEUED - The calculation has been queued for processing.
RUNNING - The calculation is running.
CANCELING - A request to cancel the calculation has been received and the system is working to stop it.
CANCELED - The calculation is no longer running as the result of a cancel request.
COMPLETED - The calculation has completed without error.
FAILED - The calculation failed and is no longer running.
Sourcepub fn set_state_filter(self, input: Option<CalculationExecutionState>) -> Self
pub fn set_state_filter(self, input: Option<CalculationExecutionState>) -> Self
A filter for a specific calculation execution state. A description of each state follows.
CREATING - The calculation is in the process of being created.
CREATED - The calculation has been created and is ready to run.
QUEUED - The calculation has been queued for processing.
RUNNING - The calculation is running.
CANCELING - A request to cancel the calculation has been received and the system is working to stop it.
CANCELED - The calculation is no longer running as the result of a cancel request.
COMPLETED - The calculation has completed without error.
FAILED - The calculation failed and is no longer running.
Sourcepub fn get_state_filter(&self) -> &Option<CalculationExecutionState>
pub fn get_state_filter(&self) -> &Option<CalculationExecutionState>
A filter for a specific calculation execution state. A description of each state follows.
CREATING - The calculation is in the process of being created.
CREATED - The calculation has been created and is ready to run.
QUEUED - The calculation has been queued for processing.
RUNNING - The calculation is running.
CANCELING - A request to cancel the calculation has been received and the system is working to stop it.
CANCELED - The calculation is no longer running as the result of a cancel request.
COMPLETED - The calculation has completed without error.
FAILED - The calculation failed and is no longer running.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of calculation executions to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of calculation executions to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of calculation executions to return.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.